//Standard Loader Panel Demo
//
// This shows how standardizing a user defined
// file loader can enable "plug-and-load" operation
//
// Create a file loader by conventions
// It should appear in the panel list for "testing"

#pragma rtGlobals=1

#pragma version=1.04
#pragma IgorVersion=6.0

#include "udFLStandardStructure", version = 1.04
#include "udFLStandardFunctions", version = 1.04

Menu "Macros"
	"Standard Loader Demo",MakeLoaderPanel()
End

// initialize

Function udFLInit(udFL)
	STRUCT udFLStandardStructure &udFL

	udFLZeroStructure(udFL)
	
	udFL.mimetype ="TEXT"
	udFL.extensions = ".txt;.dat;"
	udFL.itemsType = 1

	string cdf = GetDataFolder(1)
	
	SetDataFolder root:
	NewDataFolder/O/S Packages
	NewDataFolder/O/S SimpleFileLoaderDemo
	string/G udFLList = ""
	string/G fileList=""
	string/G userData=""
	string/G toFolder=""
	
	udFLList = FunctionList("udFileLoader*",";","KIND:6")

	SetDataFolder $cdf
	
	return 0
	
end

// some loader functions with no behavior
// just to show potential

Function udFileLoaderTabDelimitedXY(udFL)
	STRUCT udFLStandardStructure &udFL
	
	udFL.procModes = "Auto;Delimit;Slice;"
	udFL.mimetype = "TEXT"
	udFL.extensions = ".txt;"
	udFL.itemsType = 1
	udFL.itemsDim[0] = 1
	return 0

end

Function udFileLoaderJoesBarbecueGrill(udFL)
	STRUCT udFLStandardStructure &udFL
	
	udFL.procModes = "Auto;Mild;Hot;Real Spicy;"
	udFL.mimetype = "BRBQ"
	udFL.extensions = ".bbq;.grl;"
	udFL.itemsType = 2
	udFL.itemsDim[0] = 2	
	return 0

end

// some plug-ins with no behavior

Function udFLPlugInAddSomeSpice(udFL)
	STRUCT udFLStandardStructure &udFL
end

Function udFLPlugInQTXOP(udFL)
	STRUCT udFLStandardStructure &udFL
end


// get the list of loading modes

Function/S udGetFileLoaderModeList()

	ControlInfo popup0
	variable mode = V_value
	
	SVAR lFL = root:Packages:SimpleFileLoaderDemo:udFLList
	
	string loaderFunc = StringFromList(mode-1,lFL)

	if (strlen(loaderFunc)==0)
		loaderFunc = "udFLProtoFunct"
	endif
//	STRUCT udFLStandardStructure udFL
//	udFL.userCtrl = -1
		
	return (udFLQueryprocModes(loaderFunc))

end

// change things if the file loader is changed

Function udChangeFileLoader(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa
	
	STRUCT udFLStandardStructure udFL

	switch( pa.eventCode )
		case 2:
			udFL.userCtrl=-1
			PopupMenu popup1, mode = 1, value = #"udGetFileLoaderModeList()"
			break
	endswitch

	return 0
End

// make the loader panel

Function MakeLoaderPanel()

	STRUCT udFLStandardStructure udFL
	udFLInit(udFL)

	NewPanel/K=1/W=(381,55,763,264)/N=udFLPanel
	
	PopupMenu popup0,pos={21,18},size={115,20},title="File Loader",fSize=12, proc=udChangeFileLoader
	PopupMenu popup0,mode=1,value=#"FunctionList(\"udFileLoader*\",\";\",\"KIND:6\")"

	Button button0,pos={281,166},size={50,20},title="Load",fSize=14, proc=PrintudFL

	SetVariable setvar0,pos={23,136},size={300,18},title="Store @ root:",fSize=12
	SetVariable setvar0,value= root:Packages:SimpleFileLoaderDemo:toFolder

	PopupMenu popup1,pos={23,75},size={80,20},title="Mode",fSize=12
	PopupMenu popup1,mode=1,value= #"udGetFileLoaderModeList()"

	SetVariable setvar1,pos={23,108},size={250,18},title="User Data",fSize=12
	SetVariable setvar1,value= root:Packages:SimpleFileLoaderDemo:userData

	SetVariable setvar2,pos={23,44},size={300,18},title="File List",fSize=12
	SetVariable setvar2,value= root:Packages:SimpleFileLoaderDemo:fileList
	
	return 0

end

// the "load" button

Function PrintudFL(ba) : ButtonControl
	STRUCT WMButtonAction &ba
	
	STRUCT udFLStandardStructure udFL

	SVAR fileList = root:Packages:SimpleFileLoaderDemo:fileList
	SVAR userData = root:Packages:SimpleFileLoaderDemo:userData
	SVAR toFolder = root:Packages:SimpleFileLoaderDemo:toFolder
	
	switch( ba.eventCode )
		case 2: // mouse up
			udFLZeroStructure(udFL)
			ControlInfo popup0
			print "\r---\rUse loader ... ", S_value
			udFL.procModes = udFLQueryprocModes(S_value)
			udFL.userData = userData
			udFL.toFolder = toFolder
			udFL.fileList = fileList
			udFLAssureFilePaths(udFL)
			ControlInfo popup1
			udFL.userCtrl = V_value
			print udFL
			break
	endswitch

	return 0
End
