// ****************************************************
// User Defined File Loader Standard Structure
//
// Proposed Standard
// J. J. Weimer
// 2007.08.09
//
// in addition to using this structure
// "standard" file loaders should
//		return 0 if successful
//		return -1 if unsuccessful

#pragma version = 1.04
#pragma rtGlobals = 1
#pragma IgorVersion=6.0

STRUCTURE udFLStandardStructure

	// descriptors
	//------------------
	// ... these define and are to be returned
	// ... by the loader when userCtrl = 0
	
	string mimetype			// for example "TEXT"
	string extensions			// for example ".txt;.dat;.fil;"
	int32 itemsType			// bit value type of loaded item that is returned (see below)
	
		// The value of itemsType may depend on userCtrl
		// In such cases, when userCtrl = 0, the bitwise additive
		// value of itemsDim should be returned. For userCtrl != 0,
		// when file loading has completed, itemsDim must be set
		// to the proper bitwise additive value of return types
		// prior to return from the loader.
		// ...
		// BIT
		// 	0: keyword-list (nominally using "=" and ";") (ie, itemsType = 1)
		// 	1: waves (ie, itemsType = 2)
		//	2: matrix (ie, itemsType = 4)
		//	3: image (ie, itemsType = 8)
		//	4: notebook (ie, itemsType = 16)
		//	5: procedure file (ie, itemsType = 64)
		//
		// EXAMPLE
		//	itemsType = 3 means keyword-list and/or waves are returned
		//	itemsType = 80 means notebook and procedure file are returned

	int32 itemsDim[4]			// "dimension" of loaded item (see below)
	
		// This value adds additional information to the itemsType
		// Always try to return a proper value of itemsDim with userCtrl = -1
		// and itemsType = (given value) so that a user query for the
		// proper post-processing of the given loaded item in each case
		// When a certain type is not loaded, return itemsDim[N] = 0
		// When the "dimension" of an item depends on other parts of the
		// process, return itemsDim[N] = 99 (undefined)
		// itemsType			itemsDim
		//	1							[0]:	1: uses "="	2: uses ":"
		//	2					(negative itemsDim indicate TEXT waves)
		//								[0]: 	+/- 1: unscaled
		//								[0]: 	+/- 2: scaled
		//	4			(negative itemsDim indicate TEXT in given dimension)
		//						use the same convention for waves
		//						use [index] for dimension of matrix
		//					[0]: row	[1]: column	[2]: layer	[3]: chunk
		//	8							>> to be defined <<
		//	16							[0]: 	1: unformated		2: formatted
		//	64							>> to be defined <<
		
	string procModes		// list of modes that this loader provides (see below)
	
		// This string list contains the "names' of the modes that are
		// accessed with userCtrl, starting.
		// ...
		// -1: Initialize and Query (to obtain feedback accessed only at programming level)
		// 0: Initialize ONLY (accessed only at programming level)
		//   (the return strings for -1 and 0 are NOT to be part of the procModes list)
		// 1: "Normal" or "Auto" - all needed structure parameters are pre-defined
		// others: defined in sequence of access according to userCtrl

	// inputs
	//--------------
	
	int32	eventCode			// what "event" is calling the loader (see below)

			//  -1: request to kill the loader function
			// others: user defined
			
	int32	userCtrl				// process control variable (see below)
	
			// This value is always an integer input by user
			// It follows in sequence to the procModes string
			// -1: initialize and query loader (accessed only at programming level)
			// 0: initialize loader (accessed only at programming level)
			// 1: process via "normal" or "auto" load methods
			// others: user defined processing options
			
	string userData			// user string input/loader output string
	int32 reportCtrl		// control on progress reporting (see below)
			
			// -1: silent mode
			// 0: normal mode
			// 1: verbose mode
			// others: user defined "reporting" modes
			
	string plugIns				// string list of "plug-in" functions to try for processing
	
	// localizers
	// -----------------
	
	string pathStr				// path to folder
	string fileList				// list of files, for example "test.txt;scan.txt;"
	int32 returnCtrl			// control return values (see below)
	
			// 0: normal mode (no extra variables required)
			// 1: also create S_filename, V_flag, and S_value
			// others: user defined return modes
			
	string toFolder			// full path to folder where data are to be loaded
	
	// returns
	// ---------
	
	int32 itemsCount				// number of items loaded
	string itemsList				// list of item names
	int32 errCode					// error code, if any (see below)
	
			// 0: warning message only
			// -1: potentially fatal abort error
			
	string errMsg					// error message string

ENDSTRUCTURE